@@ -27,10 +27,9 @@ class ConfigurationLoader:
 
         if folder not in sys.path:
             sys.path.insert(0, folder)
-        import copy
         from entries_main import config
 
-        return copy.deepcopy(config)
+        return config
 
     def reload(self):
         """
@@ -42,11 +41,9 @@ class ConfigurationLoader:
 
         importlib.reload(entries_main)
 
-        import copy
-
         import entries_main
 
-        return copy.deepcopy(entries_main.config)
+        return entries_main.config
 
     def get_entries_project_root(self):
         """
