@@ -27,7 +27,7 @@ class RegisterNew:
 
 
     @notify_exception()
-    def register(self, *, key: str, value: str, tag: Optional[str] = None):
+    def register(self, *, key: str, value: str, type: str):
         """
         The non ui driven registering api
         Args:
@@ -38,15 +38,27 @@ class RegisterNew:
         Returns:
 
         """
-        print(f"Registering new entry with tag = {tag}")
         key = self._sanitize_key(key)
 
-        interpreter: BaseInterpreter = InterpreterMatcher.build_instance(
-            self.configuration
-        ).get_interpreter(value)
-        dict_entry = interpreter.to_dict()
-        if tag:
-            dict_entry["tags"] = [tag]
+        if not type:
+            interpreter: BaseInterpreter = InterpreterMatcher.build_instance(
+                self.configuration
+            ).get_interpreter(value)
+            dict_entry = interpreter.to_dict()
+        else:
+            if type == 'snippet':
+                dict_entry = {'snippet': value}
+            elif type == 'cli_cmd':
+                dict_entry = {'cli_cmd': value}
+            elif type == 'cmd':
+                dict_entry = {'cmd': value}
+            elif type == 'url':
+                dict_entry = {'url': value}
+            elif type == 'file':
+                dict_entry = {'file': value}
+            else:
+                raise Exception(f"Unknown type {type}")
+
 
         self.entry_inserter.insert(key, dict_entry)
 
@@ -57,8 +69,8 @@ class RegisterNew:
         data = json.load(sys.stdin)
         key = data["key"]
         value = data["value"]
-        tag = data.get("tag", None)
-        self.register(key=key, value=value, tag=tag)
+        type= data["type"]
+        self.register(key=key, value=value, type=type)
 
 
     def _sanitize_key(self, key):
