@@ -1,10 +1,22 @@
 from __future__ import annotations
 
-from python_search.events.run_performed import RunPerformed
+from python_search.events.run_performed import EntryExecuted
 
 
 class LogRunPerformedClient:
-    def send(self, data: RunPerformed):
+    def __init__(self, configuration):
+        self._configuration = configuration
+
+    def send(self, data: EntryExecuted):
+        if not self._configuration.collect_data:
+            # print("Skip collecting run performed data as collect_data is disabled")
+            return
+
+        if not self._configuration.use_webservice:
+            # print("Logging entry executed")
+            RunPerformedWriter().write(data)
+            return
+
         import requests
 
         try:
@@ -21,7 +33,7 @@ class RunPerformedWriter:
     Writes event
     """
 
-    def write(self, event: RunPerformed):
+    def write(self, event: EntryExecuted):
         import datetime
 
         event.timestamp = str(datetime.datetime.now(datetime.timezone.utc).timestamp())
