@@ -12,7 +12,7 @@ class T5Model(LLMModel):
 
         self.config = LLMConfig()
 
-        self.tokenizer = T5Tokenizer.from_pretrained(self.config.BASE_ORIGINAL_MODEL,model_max_length=512)
+        self.tokenizer = T5Tokenizer.from_pretrained(self.config.BASE_ORIGINAL_MODEL,model_max_length=512, legacy=True)
         if not logger:
             logger = setup_generic_stdout_logger()
         self.logger = logger
@@ -22,6 +22,7 @@ class T5Model(LLMModel):
     def load_productionalized_model() -> LLMModel:
         return T5Model.load_trained_model(LLMConfig().SUMMARIZATION_PRODUCTIONALIZED_MODEL)
 
+
     @staticmethod
     def load_trained_model(model_path: Optional[str] = None) -> LLMModel:
         llm_model = T5Model()
